<h1 align="center">telemetry</h1>

<p align="center">

</p>

<p align="center">

<a href="https://opensource.org/licenses/MIT">
    <img src="https://img.shields.io/pypi/l/telemetry" alt="License">
</a>
<a href="https://pypi.org/project/telemetry/">
    <img src="https://img.shields.io/pypi/dm/telemetry" alt="Downloads">
</a>
<a href="https://pypi.org/project/telemetry/">
    <img src="https://img.shields.io/pypi/pyversions/telemetry" alt="Supported Python Versions">
</a>
<a href="https://pypi.org/project/telemetry/">
    <img src="https://img.shields.io/pypi/v/telemetry" alt="PyPi Package">
</a>
</p>

## 🚀 Features

## 🔌️ Prerequisites

- [Python](https://www.python.org/) >= 3.9

## 💾 Installation

```shell
pip install exasol-telemetry
```

## 📚 Documentation

[Python Client documentation](doc/client-python.rst)

For futher details, checkout the latest [documentation](https://exasol.github.io/telemetry/).
